@@ -35,6 +35,7 @@ from .schema import Schema
 from .utils import resolve_class_attr
 
 N = TypeVar("N", bound=float)
+Derived = TypeVar("Derived", bound="Interval")
 
 
 class IntervalCheck(Protocol):
@@ -80,6 +81,12 @@ class Interval(Phantom[float], bound=Union[int, float], abstract=True):
             **kwargs,
         )
 
+    @classmethod
+    def parse(cls: type[Derived], instance: object) -> Derived:
+        return super().parse(
+            cls.__bound__(instance) if isinstance(instance, str) else instance
+        )
+
 
 def _format_limit(value: float) -> str:
     if value == inf:
